@@ -21,6 +21,16 @@ estimate_type_predictiveness <- function(arg_lst, type) {
     est_lst <- do.call(measure_mse, arg_lst)
   } else if (grepl("r_squared", type)) {
     est_lst <- do.call(measure_r_squared, arg_lst)
+  } else if (grepl("sensitivity", type)) {
+    est_lst <- do.call(measure_sensitivity(, arg_lst))
+  } else if (grepl("specificity", type)) {
+    est_lst <- do.call(measure_specificity(, arg_lst))
+  } else if (grepl("ppv", type)) {
+    est_lst <- do.call(measure_ppv(, arg_lst))
+  } else if (grepl("npv", type)) {
+    est_lst <- do.call(measure_npv(, arg_lst))
+  } else {
+    stop("The requested predictiveness measure is not available in vimp.")
   }
   return(est_lst)
 }
