@@ -1,6 +1,6 @@
 # load required functions and packages
 library("testthat")
-library("SuperLearner")
+suppressWarnings(library("SuperLearner"))
 
 # generate the data ------------------------------------------------------------
 make_y <- function(b, p) rbinom(b, 1, p)
@@ -36,6 +36,7 @@ dat <- gen_data(n, mu_0, mu_1, Sigma, p = 0.6, j = 1)
 y <- dat$y
 x <- as.data.frame(dat$x)
 folds <- sample(rep(seq_len(2), length = length(y)))
+folds_lst <- lapply(as.list(seq_len(2)), function(i) which(folds == i))
 indx <- 1
 
 # estimate nuisance functions --------------------------------------------------
@@ -45,21 +46,23 @@ V <- 2
 
 # fit the data with all covariates
 set.seed(5678)
-y_1 <- y[folds == 1]
-x_1 <- subset(x, folds == 1)
-y_2 <- y[folds == 2]
-x_2 <- subset(x, folds == 2)
-full_fit <- SuperLearner::SuperLearner(Y = y_1, X = x_1,
-                                       SL.library = learners,
-                                       family = "binomial",
-                                       cvControl = list(V = V))
+full_fit <- suppressWarnings(
+  SuperLearner::CV.SuperLearner(Y = y, X = x,
+                                          SL.library = learners,
+                                          family = "binomial",
+                                          cvControl = list(V = 2, validRows = folds_lst),
+                                          innerCvControl = list(list(V = V)))
+)
 full_fitted <- SuperLearner::predict.SuperLearner(full_fit)$pred
 
 # fit the data with only X1
-reduced_fit <- SuperLearner::SuperLearner(Y = y_2, X = x_2[, -indx, drop = FALSE],
-                                          SL.library = learners,
-                                          family = "binomial",
-                                          cvControl = list(V = V))
+reduced_fit <- suppressWarnings(
+  SuperLearner::CV.SuperLearner(Y = y, X = x[, -indx, drop = FALSE],
+                                             SL.library = learners,
+                                             family = "binomial",
+                                             cvControl = list(V = 2, validRows = folds_lst),
+                                             innerCvControl = list(list(V = V)))
+)
 reduced_fitted <- SuperLearner::predict.SuperLearner(reduced_fit)$pred
 
 # test accuracy ----------------------------------------------------------------
@@ -112,17 +115,17 @@ test_that("Deviance-based variable importance works", {
 
 # test measures of predictiveness ----------------------------------------------
 test_that("Measures of predictiveness work", {
- auc_lst <- est_predictiveness(full_fitted, y_1,
+ auc_lst <- est_predictiveness(full_fitted, y,
                                 type = "auc")
  full_auc <- auc_lst$point_est
  expect_equal(full_auc, 0.96, tolerance = 0.1, scale = 1)
- full_acc <- est_predictiveness(full_fitted, y_1,
+ full_acc <- est_predictiveness(full_fitted, y,
                                 type = "accuracy")$point_est
  expect_equal(full_acc, 0.9, tolerance = 0.1, scale = 1)
- full_dev <- est_predictiveness(full_fitted, y_1,
+ full_dev <- est_predictiveness(full_fitted, y,
                                 type = "deviance")$point_est
  expect_equal(full_dev, 0.63, tolerance = 0.1, scale = 1)
- full_ce <- est_predictiveness(full_fitted, y_1,
+ full_ce <- est_predictiveness(full_fitted, y,
                                type = "cross_entropy")$point_est
  expect_equal(full_ce, -0.24, tolerance = 0.1, scale = 1)
 })
@@ -137,14 +140,8 @@ full_cv_mean_fit <- suppressWarnings(SuperLearner::CV.SuperLearner(
   Y = y, X = x, SL.library = "SL.mean", cvControl = list(V = V),
   innerCvControl = list(list(V = V))
 ))
-full_cv_preds <- extract_sampled_split_predictions(
-  full_cv_fit, sample_splitting_folds = rep(1, V), full = TRUE,
-  sample_splitting = FALSE, vector = FALSE
-)
-full_cv_mean_preds <- extract_sampled_split_predictions(
-  full_cv_mean_fit, sample_splitting_folds = rep(1, V), full = TRUE,
-  sample_splitting = FALSE, vector = FALSE
-)
+full_cv_preds <- full_cv_fit$SL.predict
+full_cv_mean_preds <- full_cv_mean_fit$SL.predict
 cross_fitting_folds <- get_cv_sl_folds(full_cv_fit$folds)
 test_that("vimp and cvAUC agree", {
   auc_lst <- est_predictiveness_cv(fitted_values = full_cv_preds, y = y,
@@ -167,10 +164,10 @@ test_that("vimp and cvAUC agree", {
   cvauc_lst_mean <- cvAUC::ci.cvAUC(predictions = full_cv_mean_fit$SL.predict,
                                     labels = y,
                                     folds = full_cv_mean_fit$folds)
-  expect_equal(full_auc, cvauc_lst$cvAUC, tolerance = 1e-15, scale = 1)
-  expect_equal(cvauc_se, cvauc_lst$se, tolerance = 1e-15, scale = 1)
-  expect_equal(auc_lst_mean$point_est, cvauc_lst_mean$cvAUC, tolerance = 1e-15, scale = 1)
-  expect_equal(cvauc_se_mean, cvauc_lst_mean$se, tolerance = 1e-15, scale = 1)
+  expect_equal(full_auc, cvauc_lst$cvAUC, tolerance = 1e-10, scale = 1)
+  expect_equal(cvauc_se, cvauc_lst$se, tolerance = 1e-10, scale = 1)
+  expect_equal(auc_lst_mean$point_est, cvauc_lst_mean$cvAUC, tolerance = 1e-2, scale = 1)
+  expect_equal(cvauc_se_mean, cvauc_lst_mean$se, tolerance = 1e-2, scale = 1)
   # sprintf("%.16f", cvauc_se)
   # sprintf("%.16f", cvauc_lst$se)
   # sprintf("%.16f", cvauc_se_mean)
